USER_AGENT = {
    # 塞班系统:诺基亚手机浏览器(7.3.1.26)
    "Symbian":
        ("Mozilla/5.0 (SymbianOS/9.3; Series60/3.2 NokiaE5-00/071.003; Profile/MIDP-2.1 Configuration/CLDC-1.1) "
         "AppleWebKit/533.4 (KHTML, like Gecko) NokiaBrowser/7.3.1.26 Mobile Safari/533.4 3gpp-gba"),

    # Windows系统(Win10):Chrome浏览器(77.0.3865.90)
    "Win10_Chrome77":
        ("Mozilla/5.0 (Windows NT 10.0; Win64; x64) "
         "AppleWebKit/537.36 (KHTML, like Gecko) Chrome/77.0.3865.90 Safari/537.36"),

    # Windows系统(Win10):Chrome浏览器(83.0.4103.61)
    "Win10_Chrome83":
        ("Mozilla/5.0 (Windows NT 10.0; Win64; x64) "
         "AppleWebKit/537.36 (KHTML, like Gecko) Chrome/83.0.4103.61 Safari/537.36"),
}

# 默认UserAgent
DEFAULT_USER_AGENT = USER_AGENT["Win10_Chrome83"]
